@@ -1,9 +1,9 @@
 package Inline::C;
-our $VERSION = '0.56_01';
-$VERSION = '0.56_01';
+our $VERSION = '0.56_02';
+$VERSION = eval $VERSION;
 
 use strict;
-use Inline 0.56_01;
+use Inline 0.56;
 use Config;
 use Data::Dumper;
 use Carp;
